#!/usr/bin/env pytest
###############################################################################
# $Id$
#
# Project:  GDAL/OGR Test Suite
# Purpose:  Test VSI path specific options
# Author:   Even Rouault <even dot rouault at spatialys dot com>
#
###############################################################################
# Copyright (c) 2022 Even Rouault <even dot rouault at spatialys dot com>
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.
###############################################################################

import pytest

from osgeo import gdal


def test_vsi_path_specific_options():

    with pytest.raises(Exception):
        assert gdal.GetPathSpecificOption(None, "key")

    with pytest.raises(Exception):
        assert gdal.GetPathSpecificOption("prefix", None)

    assert gdal.GetPathSpecificOption("prefix", "key") is None

    assert gdal.GetPathSpecificOption("prefix", "key", "default") == "default"

    with pytest.raises(Exception):
        gdal.SetPathSpecificOption(None, "key", "value")

    with pytest.raises(Exception):
        gdal.SetPathSpecificOption("prefix", None, "value")

    gdal.SetPathSpecificOption("prefix", "key", "value")
    assert gdal.GetPathSpecificOption("prefix", "key") == "value"
    assert gdal.GetPathSpecificOption("prefix/object", "key") == "value"
    assert gdal.GetPathSpecificOption("prefix", "key", "default") == "value"
    assert gdal.GetPathSpecificOption("another_prefix", "key") is None

    gdal.SetPathSpecificOption("prefix", "key", None)
    assert gdal.GetPathSpecificOption("prefix", "key") is None

    gdal.SetPathSpecificOption("prefix", "key", "value")
    gdal.ClearPathSpecificOptions("prefix")
    assert gdal.GetPathSpecificOption("prefix", "key") is None

    gdal.SetPathSpecificOption("prefix", "key", "value")
    gdal.ClearPathSpecificOptions("another_prefix")
    assert gdal.GetPathSpecificOption("prefix", "key") == "value"
    gdal.ClearPathSpecificOptions()
    assert gdal.GetPathSpecificOption("prefix", "key") is None
